@@ -17,6 +17,21 @@ init <- MatTrans.init(Y, K = K, n.start = 2)
 
 
 M <- MatTrans.EM(Y, initial = init, la = matrix(1.1,K,p),
-                 nu = matrix(1.1,K,T), model = "A-EVE-VV", 
-                 trans = "Power")
+  nu = matrix(1.1,K,T), model = "A-EVE-VV", trans = "Power")
+
+M$best.result
+
+M$model
+
+M$loglik
+
+M$bic
+
+M$best.model
+
+M$best.loglik
+
+M$best.bic
+
+M$trans
 
